==> quanyi-center-api-1.1.21-20240711.032711-4-sources.jar: cn/com/duiba/quanyi/center/api/param/coupon/AlipayCountCoinsActivitySaveOrUpdateParam.java <==
package cn.com.duiba.quanyi.center.api.param.coupon;

import lombok.Data;
import lombok.ToString;

import java.io.Serializable;
import java.util.Date;

/**
 * AlipayActivitySaveOrUpdateParam
 * @author yangyukang
 */
@Data
@ToString
public class AlipayCountCoinsActivitySaveOrUpdateParam implements Serializable {

    private static final long serialVersionUID = -7721521073173220104L;
    /**
     * 主键
     */
    private Long id;

    /**
     * 总库存
     */
    private Long totalNum;

    /**
     * 支付宝分配给开发者的应用ID
     */
    private String alipayAppId;

    /**
     * 支付宝数币活动名称
     */
    private String countCoinsName;

    /**
     * 支付宝数币活动ID
     */
    private String alipayActId;

    /**
     * 支付宝数币活动状态
     */
    private Integer alipayActStatus;

    /**
     * 优惠立减值, 分为单位如果discount_type=reduce，那么就是具体的优惠立减额，比如：999代表满足一定金额减9.99元；如果discount_type=random，那么就是"最小额-最大额"，比如:99-990，代表立减范围从0.99元到9.99元随机决策
     */
    private Long discountValue;

    /**
     * 优惠立减门槛金额 以分为单位
     */
    private Long discountThresholdAmt;

    /**
     * 发放开始时间
     */
    private Date startTime;

    /**
     * 发放结束时间
     */
    private Date endTime;

    /**
     * 总预算
     */
    private Long totalBudget;

    /**
     * 活动规则
     */
    private String activityRule;

    /**
     * 创建人操作Id,ssoid
     */
    private Long createOperatorId;

    /**
     * 创建人操作Id,ssoname
     */
    private String createOperatorName;

    /**
     * 需求主键, tb_demand.id
     */
    private Long demandId;

    /**
     * 采购商品主键, tb_purchase_goods.id
     */
    private Long demandGoodsId;

    /**
     * 商品规格ID
     */
    private Long skuId;

    /**
     * 短链前端页面ID
     */
    private String pageId;

}

==> quanyi-center-api-1.4.89-sources.jar: cn/com/duiba/quanyi/center/api/param/coupon/AlipayCountCoinsActivitySaveOrUpdateParam.java <==
package cn.com.duiba.quanyi.center.api.param.coupon;

import cn.com.duiba.quanyi.center.api.enums.alipay.AlipayActivityBizStatusEnum;
import cn.com.duiba.quanyi.center.api.enums.alipay.AlipayCoinsActTypeEnum;
import lombok.Data;
import lombok.ToString;

import java.io.Serializable;
import java.util.Date;

/**
 * AlipayActivitySaveOrUpdateParam
 * @author yangyukang
 */
@Data
@ToString
public class AlipayCountCoinsActivitySaveOrUpdateParam implements Serializable {

    private static final long serialVersionUID = -7721521073173220104L;
    /**
     * 主键
     */
    private Long id;

    /**
     * 总库存
     */
    private Long totalNum;

    /**
     * 支付宝分配给开发者的应用ID
     */
    private String alipayAppId;

    /**
     * 支付宝数币活动名称
     */
    private String countCoinsName;

    /**
     * 支付宝数币活动ID
     */
    private String alipayActId;

    /**
     * 支付宝数币活动状态
     */
    private Integer alipayActStatus;

    /**
     * 优惠立减值, 分为单位如果discount_type=single，那么就是具体的优惠立减额，比如：999代表满足一定金额减9.99元；如果是其他类型，存储JSON字符串
     */
    private Long discountValue;

    /**
     * 优惠立减门槛金额 以分为单位
     */
    private Long discountThresholdAmt;

    /**
     * 发放开始时间
     */
    private Date startTime;

    /**
     * 发放结束时间
     */
    private Date endTime;

    /**
     * 总预算
     */
    private Long totalBudget;

    /**
     * 活动规则
     */
    private String activityRule;

    /**
     * 创建人操作Id,ssoid
     */
    private Long createOperatorId;

    /**
     * 创建人操作Id,ssoname
     */
    private String createOperatorName;

    /**
     * 需求主键, tb_demand.id
     */
    private Long demandId;

    /**
     * 采购商品主键, tb_purchase_goods.id
     */
    private Long demandGoodsId;

    /**
     * 商品规格ID
     */
    private Long skuId;

    /**
     * 项目id
     */
    private Long projectId;

    /**
     * 短链前端页面ID
     */
    private String pageId;

    /**
     * 模板id
     */
    private String templateId;

    /**
     * 是否是聚宝盆发放
     * @see cn.com.duiba.quanyi.center.api.enums.BooleanEnum
     */
    private Integer grantFlag;

    /**
     * 商户号
     */
    private String mchCode;

    /**
     * 业务状态：1-待分配, 2-已分配
     * {@link AlipayActivityBizStatusEnum}
     */
    private Integer bizStatus;

    /**
     * 批次类型
     * @see AlipayCoinsActTypeEnum
     */
    private Integer alipayActType;

    /**
     * 退款结算截止日
     */
    private Date settlementDeadlineTime;
}
